@@ -1,23 +1,19 @@
 import json
 import random
+from functools import partial
 from pathlib import Path
 from tempfile import TemporaryDirectory
 
 import json_stream as js
 from contexttimer import Timer
+from json_stream.tokenizer import tokenize as pure_python_tokenizer
+from json_stream_to_standard_types import to_standard_types
 from tqdm import tqdm
 
 import json_stream_rs_tokenizer as jsrs
 
 from .random_json_generator import RandomJsonGenerator
 
-try:
-    js.to_standard_types
-except AttributeError as e:
-    raise ImportError(
-        "benchmarks currently require a patched version of json-stream"
-    ) from e
-
 
 def shuffled(l):
     return random.sample(l, k=len(l))
@@ -39,8 +35,8 @@ def main(json_bytes=2e6):
         results = {"python": {}, "rust": {}, "non-streaming": {}}
         for tokenizer_type, load_fn in shuffled(
             [
-                ("python", js.load),
-                ("rust", jsrs.load),
+                ("python", partial(js.load, tokenizer=pure_python_tokenizer)),
+                ("rust", partial(js.load, tokenizer=jsrs.RustTokenizer)),
                 ("non-streaming", json.load),
             ]
         ):
@@ -48,9 +44,7 @@ def main(json_bytes=2e6):
             with Timer() as t:
                 with random_json_file_path.open() as f:
                     l = load_fn(f)
-                    parsed = [
-                        js.to_standard_types(x) for x in tqdm(l, total=100)
-                    ]
+                    parsed = [to_standard_types(x) for x in tqdm(l, total=100)]
             print(f"{tokenizer_type} time: {t.elapsed:.2f} s")
             results[tokenizer_type]["elapsed"] = t.elapsed
             results[tokenizer_type]["parsed"] = parsed
